<h1 align="center">OpenDebates for Discord</h1>
<p align="center">
    <a href="https://opendebates.rtfd.io"><img width="100" src="https://i.imgur.com/SxX5wQF.png"/></a>
</p>
<p align="center">
    <br>
    <br>
    <a href="https://github.com/OpenDebates/OpenDebates/actions/workflows/main.yml">
        <img src="https://github.com/OpenDebates/OpenDebates/actions/workflows/main.yml/badge.svg"/>
    </a>
    <a href="https://opendebates.readthedocs.io/en/latest/?badge=latest">
        <img src="https://readthedocs.org/projects/opendebates/badge/?version=latest" alt='Documentation Status'/>
    </a>
</p>
<hr>
<h4>What is OpenDebates for Discord?</h4>
    <p>It is a bot for discord, that allows users to participate in debates that are ranked by ELO ratings.</p>
